![CI](https://github.com/tellor-io/pytelliot/actions/workflows/py39.yml/badge.svg)
![Docs](https://github.com/tellor-io/pytelliot/actions/workflows/docs.yml/badge.svg)
[![codecov](https://codecov.io/gh/tellor-io/pytelliot/branch/main/graph/badge.svg?token=S1199HQ2EK)](https://codecov.io/gh/tellor-io/pytelliot)
[![Discord Chat](https://img.shields.io/discord/461602746336935936)](https://discord.com/invite/n7drGjh)
[![Twitter Follow](https://img.shields.io/twitter/follow/wearetellor?style=social)](https://twitter.com/WeAreTellor)

# Telliot Core

Telliot is a command line tool and software development kit (SDK) for interacting with the [Tellor protocol](https://docs.tellor.io/tellor/whitepaper/introduction).

- [Documentation](https://tellor-io.github.io/telliot-core/)
- [Contributing](https://tellor-io.github.io/telliot-core/contributing/)

To become a Tellor reporter, begin by installing the
[telliot-feeds](https://github.com/tellor-io/telliot-feeds) package.
